==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/NetworkTapRuleMatchConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs.builder
import com.pulumi.azurenative.managednetworkfabric.kotlin.enums.IPAddressType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines the match configuration that are supported to filter the traffic.
 * @property actions List of actions that need to be performed for the matched conditions.
 * @property ipAddressType Type of IP Address. IPv4 or IPv6
 * @property matchConditions List of the match conditions.
 * @property matchConfigurationName The name of the match configuration.
 * @property sequenceNumber Sequence Number of the match configuration..
 */
public data class NetworkTapRuleMatchConfigurationArgs(
    public val actions: Output<List<NetworkTapRuleActionArgs>>? = null,
    public val ipAddressType: Output<Either<String, IPAddressType>>? = null,
    public val matchConditions: Output<List<NetworkTapRuleMatchConditionArgs>>? = null,
    public val matchConfigurationName: Output<String>? = null,
    public val sequenceNumber: Output<Double>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs.builder()
            .actions(
                actions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ipAddressType(
                ipAddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .matchConditions(
                matchConditions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .matchConfigurationName(matchConfigurationName?.applyValue({ args0 -> args0 }))
            .sequenceNumber(sequenceNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkTapRuleMatchConfigurationArgs].
 */
@PulumiTagMarker
public class NetworkTapRuleMatchConfigurationArgsBuilder internal constructor() {
    private var actions: Output<List<NetworkTapRuleActionArgs>>? = null

    private var ipAddressType: Output<Either<String, IPAddressType>>? = null

    private var matchConditions: Output<List<NetworkTapRuleMatchConditionArgs>>? = null

    private var matchConfigurationName: Output<String>? = null

    private var sequenceNumber: Output<Double>? = null

    /**
     * @param value List of actions that need to be performed for the matched conditions.
     */
    @JvmName("iyeqlcenivhggtnx")
    public suspend fun actions(`value`: Output<List<NetworkTapRuleActionArgs>>) {
        this.actions = value
    }

    @JvmName("nodoybatffqeupvg")
    public suspend fun actions(vararg values: Output<NetworkTapRuleActionArgs>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values List of actions that need to be performed for the matched conditions.
     */
    @JvmName("hxvoiedhahishwlx")
    public suspend fun actions(values: List<Output<NetworkTapRuleActionArgs>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("xrppsklcmhxlaqdj")
    public suspend fun ipAddressType(`value`: Output<Either<String, IPAddressType>>) {
        this.ipAddressType = value
    }

    /**
     * @param value List of the match conditions.
     */
    @JvmName("vggijpixadearpcn")
    public suspend fun matchConditions(`value`: Output<List<NetworkTapRuleMatchConditionArgs>>) {
        this.matchConditions = value
    }

    @JvmName("wxgqftubyiqpptom")
    public suspend fun matchConditions(vararg values: Output<NetworkTapRuleMatchConditionArgs>) {
        this.matchConditions = Output.all(values.asList())
    }

    /**
     * @param values List of the match conditions.
     */
    @JvmName("oqxmcuqkfyxpqvvo")
    public suspend fun matchConditions(values: List<Output<NetworkTapRuleMatchConditionArgs>>) {
        this.matchConditions = Output.all(values)
    }

    /**
     * @param value The name of the match configuration.
     */
    @JvmName("sxtxvwkbehidevjc")
    public suspend fun matchConfigurationName(`value`: Output<String>) {
        this.matchConfigurationName = value
    }

    /**
     * @param value Sequence Number of the match configuration..
     */
    @JvmName("xsssydbmsatyvjbv")
    public suspend fun sequenceNumber(`value`: Output<Double>) {
        this.sequenceNumber = value
    }

    /**
     * @param value List of actions that need to be performed for the matched conditions.
     */
    @JvmName("lenkpckhoqltpxxw")
    public suspend fun actions(`value`: List<NetworkTapRuleActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param argument List of actions that need to be performed for the matched conditions.
     */
    @JvmName("urrvljbjmcsumdfm")
    public suspend fun actions(argument: List<suspend NetworkTapRuleActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleActionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param argument List of actions that need to be performed for the matched conditions.
     */
    @JvmName("vmpukidicupqomkx")
    public suspend fun actions(vararg argument: suspend NetworkTapRuleActionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleActionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param argument List of actions that need to be performed for the matched conditions.
     */
    @JvmName("sqfmbinymxlfnxua")
    public suspend fun actions(argument: suspend NetworkTapRuleActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NetworkTapRuleActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param values List of actions that need to be performed for the matched conditions.
     */
    @JvmName("jgbpcvlvocvcyoiq")
    public suspend fun actions(vararg values: NetworkTapRuleActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("lrqqksioyqpsmylm")
    public suspend fun ipAddressType(`value`: Either<String, IPAddressType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddressType = mapped
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("crraweaviqhbgrwj")
    public fun ipAddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAddressType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipAddressType = mapped
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("xwfyrjjfjrewbwpd")
    public fun ipAddressType(`value`: IPAddressType) {
        val toBeMapped = Either.ofRight<String, IPAddressType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipAddressType = mapped
    }

    /**
     * @param value List of the match conditions.
     */
    @JvmName("mnmaryeqcfqpwwjr")
    public suspend fun matchConditions(`value`: List<NetworkTapRuleMatchConditionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param argument List of the match conditions.
     */
    @JvmName("eodesifkpvbylulw")
    public suspend
    fun matchConditions(argument: List<suspend NetworkTapRuleMatchConditionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of the match conditions.
     */
    @JvmName("dxcajnlsffhalswp")
    public suspend fun matchConditions(
        vararg
        argument: suspend NetworkTapRuleMatchConditionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of the match conditions.
     */
    @JvmName("sbdoomgvorrjrtqc")
    public suspend
    fun matchConditions(argument: suspend NetworkTapRuleMatchConditionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            NetworkTapRuleMatchConditionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param values List of the match conditions.
     */
    @JvmName("tarcnvgmrbbobnon")
    public suspend fun matchConditions(vararg values: NetworkTapRuleMatchConditionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param value The name of the match configuration.
     */
    @JvmName("lldtghqngpaftfur")
    public suspend fun matchConfigurationName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchConfigurationName = mapped
    }

    /**
     * @param value Sequence Number of the match configuration..
     */
    @JvmName("rayvurbwdqjnkahq")
    public suspend fun sequenceNumber(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sequenceNumber = mapped
    }

    internal fun build(): NetworkTapRuleMatchConfigurationArgs = NetworkTapRuleMatchConfigurationArgs(
        actions = actions,
        ipAddressType = ipAddressType,
        matchConditions = matchConditions,
        matchConfigurationName = matchConfigurationName,
        sequenceNumber = sequenceNumber,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/NetworkTapRuleMatchConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs.builder
import com.pulumi.azurenative.managednetworkfabric.kotlin.enums.IPAddressType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines the match configuration that are supported to filter the traffic.
 * @property actions List of actions that need to be performed for the matched conditions.
 * @property ipAddressType Type of IP Address. IPv4 or IPv6
 * @property matchConditions List of the match conditions.
 * @property matchConfigurationName The name of the match configuration.
 * @property sequenceNumber Sequence Number of the match configuration..
 */
public data class NetworkTapRuleMatchConfigurationArgs(
    public val actions: Output<List<NetworkTapRuleActionArgs>>? = null,
    public val ipAddressType: Output<Either<String, IPAddressType>>? = null,
    public val matchConditions: Output<List<NetworkTapRuleMatchConditionArgs>>? = null,
    public val matchConfigurationName: Output<String>? = null,
    public val sequenceNumber: Output<Double>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.NetworkTapRuleMatchConfigurationArgs.builder()
            .actions(
                actions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ipAddressType(
                ipAddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .matchConditions(
                matchConditions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .matchConfigurationName(matchConfigurationName?.applyValue({ args0 -> args0 }))
            .sequenceNumber(sequenceNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkTapRuleMatchConfigurationArgs].
 */
@PulumiTagMarker
public class NetworkTapRuleMatchConfigurationArgsBuilder internal constructor() {
    private var actions: Output<List<NetworkTapRuleActionArgs>>? = null

    private var ipAddressType: Output<Either<String, IPAddressType>>? = null

    private var matchConditions: Output<List<NetworkTapRuleMatchConditionArgs>>? = null

    private var matchConfigurationName: Output<String>? = null

    private var sequenceNumber: Output<Double>? = null

    /**
     * @param value List of actions that need to be performed for the matched conditions.
     */
    @JvmName("rtbpknkvqdicpsvq")
    public suspend fun actions(`value`: Output<List<NetworkTapRuleActionArgs>>) {
        this.actions = value
    }

    @JvmName("bposiqtayepmaenb")
    public suspend fun actions(vararg values: Output<NetworkTapRuleActionArgs>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values List of actions that need to be performed for the matched conditions.
     */
    @JvmName("fylspypnlqqcksfj")
    public suspend fun actions(values: List<Output<NetworkTapRuleActionArgs>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("fmcrdeqctxbktbyv")
    public suspend fun ipAddressType(`value`: Output<Either<String, IPAddressType>>) {
        this.ipAddressType = value
    }

    /**
     * @param value List of the match conditions.
     */
    @JvmName("kfmtubrqiqyyfsyi")
    public suspend fun matchConditions(`value`: Output<List<NetworkTapRuleMatchConditionArgs>>) {
        this.matchConditions = value
    }

    @JvmName("sjcoajyqfgxmecui")
    public suspend fun matchConditions(vararg values: Output<NetworkTapRuleMatchConditionArgs>) {
        this.matchConditions = Output.all(values.asList())
    }

    /**
     * @param values List of the match conditions.
     */
    @JvmName("dntvkkwiaocwdbnl")
    public suspend fun matchConditions(values: List<Output<NetworkTapRuleMatchConditionArgs>>) {
        this.matchConditions = Output.all(values)
    }

    /**
     * @param value The name of the match configuration.
     */
    @JvmName("tldeqijbqhvcjdlf")
    public suspend fun matchConfigurationName(`value`: Output<String>) {
        this.matchConfigurationName = value
    }

    /**
     * @param value Sequence Number of the match configuration..
     */
    @JvmName("ibagtuhxkdxpagie")
    public suspend fun sequenceNumber(`value`: Output<Double>) {
        this.sequenceNumber = value
    }

    /**
     * @param value List of actions that need to be performed for the matched conditions.
     */
    @JvmName("weijmoqdpmmuwnmp")
    public suspend fun actions(`value`: List<NetworkTapRuleActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param argument List of actions that need to be performed for the matched conditions.
     */
    @JvmName("jtfdwpdlmbjmfphf")
    public suspend fun actions(argument: List<suspend NetworkTapRuleActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleActionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param argument List of actions that need to be performed for the matched conditions.
     */
    @JvmName("bhaengfqpvflfyyo")
    public suspend fun actions(vararg argument: suspend NetworkTapRuleActionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleActionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param argument List of actions that need to be performed for the matched conditions.
     */
    @JvmName("gjjrwxltrokoctst")
    public suspend fun actions(argument: suspend NetworkTapRuleActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NetworkTapRuleActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param values List of actions that need to be performed for the matched conditions.
     */
    @JvmName("qklswgajirjwkugu")
    public suspend fun actions(vararg values: NetworkTapRuleActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("cakggeepfhkxtwgl")
    public suspend fun ipAddressType(`value`: Either<String, IPAddressType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddressType = mapped
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("spcnqvfkcawdvfjd")
    public fun ipAddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAddressType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipAddressType = mapped
    }

    /**
     * @param value Type of IP Address. IPv4 or IPv6
     */
    @JvmName("heammffysomkqhpi")
    public fun ipAddressType(`value`: IPAddressType) {
        val toBeMapped = Either.ofRight<String, IPAddressType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipAddressType = mapped
    }

    /**
     * @param value List of the match conditions.
     */
    @JvmName("torgxjilemvfhjeh")
    public suspend fun matchConditions(`value`: List<NetworkTapRuleMatchConditionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param argument List of the match conditions.
     */
    @JvmName("pbwacfsqwsswrulv")
    public suspend
    fun matchConditions(argument: List<suspend NetworkTapRuleMatchConditionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of the match conditions.
     */
    @JvmName("jpktcsvdqguuqjnw")
    public suspend fun matchConditions(
        vararg
        argument: suspend NetworkTapRuleMatchConditionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NetworkTapRuleMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of the match conditions.
     */
    @JvmName("etcyfvbtfhumbdsp")
    public suspend
    fun matchConditions(argument: suspend NetworkTapRuleMatchConditionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            NetworkTapRuleMatchConditionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param values List of the match conditions.
     */
    @JvmName("vanbrpsnvoeshuaw")
    public suspend fun matchConditions(vararg values: NetworkTapRuleMatchConditionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param value The name of the match configuration.
     */
    @JvmName("fqnqpnsbqlcffbtq")
    public suspend fun matchConfigurationName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchConfigurationName = mapped
    }

    /**
     * @param value Sequence Number of the match configuration..
     */
    @JvmName("tftcvxuxhdyyowdn")
    public suspend fun sequenceNumber(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sequenceNumber = mapped
    }

    internal fun build(): NetworkTapRuleMatchConfigurationArgs = NetworkTapRuleMatchConfigurationArgs(
        actions = actions,
        ipAddressType = ipAddressType,
        matchConditions = matchConditions,
        matchConfigurationName = matchConfigurationName,
        sequenceNumber = sequenceNumber,
    )
}
